@@ -9,7 +9,7 @@ window.onload = function() {
     var data = videoDB.getPage(videoDB.getPageNumber());
     refreshVideos(undefined, data);
   });
-
+  videoDB.resetPage();
   refreshPagination();
   return false;
 };
@@ -84,7 +84,7 @@ function refreshPagination() {
 	if (pageCount > 1) {
 	    var pageText = document.getElementById('pagination-text');
 	    var pageNumber = videoDB.getPageNumber();
-	    pageText.innerHTML = 'Page ' + pageNumber + '/' + pageCount;
+	    pageText.innerHTML += ' ' + pageNumber + '/' + pageCount;
 	    
 	    if (videoDB.getPageNumber() == 1) {
 		leftArrow.style.visibility = 'hidden';
@@ -126,11 +126,11 @@ function refreshVideos(language, pageData) {
       var li = document.createElement('li');
       
       var a = document.createElement('a')
-      a.href =  video['id']+'.html?lang=' + lang;
+      a.href =  video['slug']+'?lang=' + lang;
       a.className = 'nostyle'
 
       var img = document.createElement('img');
-      img.src = ZIM_IMG_NS+'videos/'+video['id']+'/thumbnail.jpg';
+      img.src = ZIM_IMG_NS+'videos/'+video['id']+'/thumbnail.webp';
 
       var author = document.createElement('p');
       author.id = 'author';
